@@ -1,8 +1,8 @@
 matchit2genetic <- function(treat, X, data, distance, discarded,
                             ratio = 1, verbose = FALSE, ...) {
-  if (!("rgenoud" %in% .packages(all = TRUE)))
-    install.packages("rgenoud")
-  require(rgenoud)
+  #if (!("rgenoud" %in% .packages(all = TRUE)))
+  #  install.packages("rgenoud")
+  #require(rgenoud)
 
   if (!("Matching" %in% .packages(all = TRUE)))
     install.packages("Matching")
